@@ -1,30 +1,32 @@
-/*
-    GNOME Commander - A GNOME based file manager
-    Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013-2016 Uwe Scholz
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-*/
+/** 
+ * @file gnome-cmd-file-selector.cc
+ * @copyright (C) 2001-2006 Marcus Bjurman\n
+ * @copyright (C) 2007-2012 Piotr Eljasiak\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
+ *
+ * @copyright This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * @copyright This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * @copyright You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
 
 #include <config.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-con-list.h"
+#ifdef HAVE_SAMBA
 #include "gnome-cmd-con-smb.h"
+#endif
 #include "gnome-cmd-combo.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-cmdline.h"
@@ -323,7 +325,7 @@ static void on_con_combo_item_selected (GnomeCmdCombo *con_combo, GnomeCmdCon *c
     if (mask & GDK_CONTROL_MASK || fs->file_list()->locked)
         fs->new_tab(gnome_cmd_con_get_default_dir (con));
     else
-        fs->set_connection(con);
+	fs->set_connection(con, gnome_cmd_con_get_default_dir (con));
 }
 
 
@@ -352,7 +354,7 @@ static void on_con_btn_clicked (GtkWidget *widget, GdkEventButton *event, GnomeC
     if (event->button==2 || event->state&GDK_CONTROL_MASK || fs->file_list()->locked)
         fs->new_tab(gnome_cmd_con_get_default_dir (con));
 
-    fs->set_connection(con);
+    fs->set_connection(con, gnome_cmd_con_get_default_dir (con));
 }
 
 
@@ -360,7 +362,7 @@ static void create_con_buttons (GnomeCmdFileSelector *fs)
 {
     static GtkTooltips *tooltips = NULL;
 
-    if (!gnome_cmd_data.conbuttons_visibility)
+    if (!gnome_cmd_data.show_devbuttons)
         return;
 
     for (GList *l = fs->priv->old_btns; l; l=l->next)
@@ -376,8 +378,12 @@ static void create_con_buttons (GnomeCmdFileSelector *fs)
     {
         GnomeCmdCon *con = GNOME_CMD_CON (l->data);
 
+#ifdef HAVE_SAMBA
         if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con) &&
             !GNOME_CMD_IS_CON_SMB (con))  continue;
+#else
+        if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con))  continue;
+#endif
 
         GnomeCmdPixmap *pm = gnome_cmd_con_get_go_pixmap (con);
 
@@ -625,7 +631,7 @@ static gboolean on_notebook_button_pressed (GtkWidget *widget, GdkEventButton *e
                     {
                         GnomeCmdFileList *fl = fs->file_list(tab_clicked);
 
-                        if (!fl->locked || gnome_cmd_prompt_message (*main_win, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, _("The tab is locked, close anyway ?"))==GTK_RESPONSE_OK)
+                        if (!fl->locked || gnome_cmd_prompt_message (*main_win, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, _("The tab is locked, close anyway?"))==GTK_RESPONSE_OK)
                             fs->close_tab(tab_clicked);
                     }
 
@@ -700,7 +706,7 @@ static gboolean on_notebook_button_pressed (GtkWidget *widget, GdkEventButton *e
             {
                 GnomeCmdFileList *fl = fs->file_list(tab_clicked);
 
-                if (!fl->locked || gnome_cmd_prompt_message (*main_win, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, _("The tab is locked, close anyway ?"))==GTK_RESPONSE_OK)
+                if (!fl->locked || gnome_cmd_prompt_message (*main_win, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, _("The tab is locked, close anyway?"))==GTK_RESPONSE_OK)
                     fs->close_tab(tab_clicked);
             }
             else
@@ -759,6 +765,9 @@ static void class_init (GnomeCmdFileSelectorClass *klass)
 
 static void init (GnomeCmdFileSelector *fs)
 {
+    gint string_size = 0;
+    gint max_string_size = 150;
+
     fs->list = NULL;
 
     fs->priv = new GnomeCmdFileSelector::Private;
@@ -766,7 +775,7 @@ static void init (GnomeCmdFileSelector *fs)
     GtkVBox *vbox = GTK_VBOX (fs);
 
     // create the box used for packing the dir_combo and buttons
-    fs->update_conbuttons_visibility();
+    fs->update_show_devbuttons();
 
     // create the box used for packing the con_combo and information
     fs->con_hbox = create_hbox (*fs, FALSE, 2);
@@ -774,11 +783,29 @@ static void init (GnomeCmdFileSelector *fs)
     // create the notebook and the first tab
     fs->notebook = new GnomeCmdNotebook;
 
+    for (GList *l=gnome_cmd_con_list_get_all (gnome_cmd_con_list_get ()); l; l = l->next)
+    {
+        gchar *text;
+        GnomeCmdCon *con = (GnomeCmdCon *) l->data;
+
+#ifdef HAVE_SAMBA
+        if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con)
+            && !GNOME_CMD_IS_CON_SMB (con))  continue;
+#else
+        if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con))  continue;
+#endif
+
+        text = g_strdup_printf("%s  ",(gchar *) gnome_cmd_con_get_alias (con));
+        string_size = get_string_pixel_size (text, strlen(text));
+        max_string_size = string_size > max_string_size ? string_size : max_string_size;
+        g_free(text);
+    }
+
     // create the connection combo
     fs->con_combo = new GnomeCmdCombo(2, 1);
     g_object_ref (fs->con_combo);
     g_object_set_data_full (*fs, "con_combo", fs->con_combo, g_object_unref);
-    gtk_widget_set_size_request (*fs->con_combo, 150, -1);
+    gtk_widget_set_size_request (*fs->con_combo, max_string_size, -1);
     gtk_clist_set_row_height (GTK_CLIST (fs->con_combo->list), 20);
     gtk_entry_set_editable (GTK_ENTRY (fs->con_combo->entry), FALSE);
     gtk_clist_set_column_width (GTK_CLIST (fs->con_combo->list), 0, 20);
@@ -810,7 +837,11 @@ static void init (GnomeCmdFileSelector *fs)
     gtk_box_pack_start (GTK_BOX (vbox), padding, FALSE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (padding), fs->info_label, FALSE, TRUE, 6);
     gtk_box_pack_start (GTK_BOX (fs->con_hbox), *fs->con_combo, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (fs->con_hbox), fs->vol_label, TRUE, TRUE, 6);
+    // changing this value has only an effect when restarting gcmd
+    if (gnome_cmd_data.show_devlist)
+        gtk_box_pack_start (GTK_BOX (fs->con_hbox), fs->vol_label, TRUE, TRUE, 6);
+    else
+        gtk_box_pack_start (GTK_BOX (padding), fs->vol_label, TRUE, TRUE, 6);
 
     // connect signals
     g_signal_connect (fs, "realize", G_CALLBACK (on_realize), fs);
@@ -822,7 +853,7 @@ static void init (GnomeCmdFileSelector *fs)
 
     // show the widgets
     gtk_widget_show (GTK_WIDGET (vbox));
-    fs->update_concombo_visibility();
+    fs->update_show_devlist();
     gtk_widget_show (*fs->con_combo);
     gtk_widget_show (fs->vol_label);
     gtk_widget_show (fs->dir_indicator);
@@ -988,8 +1019,12 @@ void GnomeCmdFileSelector::update_connections()
         gchar *text[3];
         GnomeCmdCon *con = (GnomeCmdCon *) l->data;
 
+#ifdef HAVE_SAMBA
         if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con)
             && !GNOME_CMD_IS_CON_SMB (con))  continue;
+#else
+        if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con))  continue;
+#endif
 
         if (con == get_connection())
             found_my_con = TRUE;
@@ -1321,9 +1356,9 @@ void gnome_cmd_file_selector_create_symlinks (GnomeCmdFileSelector *fs, GList *f
 }
 
 
-void GnomeCmdFileSelector::update_conbuttons_visibility()
+void GnomeCmdFileSelector::update_show_devbuttons()
 {
-    if (!gnome_cmd_data.conbuttons_visibility)
+    if (!gnome_cmd_data.show_devbuttons)
     {
         if (con_btns_hbox)
         {
@@ -1345,9 +1380,9 @@ void GnomeCmdFileSelector::update_conbuttons_visibility()
 }
 
 
-void GnomeCmdFileSelector::update_concombo_visibility()
+void GnomeCmdFileSelector::update_show_devlist()
 {
-    if (gnome_cmd_data.concombo_visibility)
+    if (gnome_cmd_data.show_devlist)
         gtk_widget_show (con_hbox);
     else
         gtk_widget_hide (con_hbox);
